@@ -14,7 +14,7 @@ class LogAdmin(admin.ModelAdmin):
 class ReportAdmin(admin.ModelAdmin):
     using = 'log'
 
-    list_display = ['index', 'status', 'created_at']
+    list_display = ['id', 'index', 'status', 'created_at']
     list_filter = ['created_at', 'status', 'index']
     search_fields = ['index']
 
