@@ -1,19 +1,23 @@
-class LogRouter:
-    route_app_labels = ['logs']
+from django.db.utils import ConnectionRouter
+from django.db.models import Model
 
-    def db_for_read(self, model, **hints):
+
+class LogRouter(ConnectionRouter):
+    route_app_labels = {'logs'}
+
+    def db_for_read(self, model: Model, **hints):
         """ reading Log from log """
         if model._meta.app_label in self.route_app_labels:
             return 'log'
         return None
 
-    def db_for_write(self, model, **hints):
+    def db_for_write(self, model: Model, **hints):
         """ writing Log to log """
         if model._meta.app_label in self.route_app_labels:
             return 'log'
         return None
 
-    def allow_relation(self, obj1, obj2, **hints):
+    def allow_relation(self, obj1: Model, obj2: Model, **hints):
         """
         Allow relations if a model in the log apps is
         involved.
@@ -32,6 +36,7 @@ class LogRouter:
         """
         if app_label in self.route_app_labels:
             return db == 'log'
-        return None
-
-
+        elif db == 'log':
+            return False
+        else:
+            pass
